# Unpaywall

"Unpaywall is a project of Our Research, a nonprofit building tools to help make scholarly
research more open, accessible, and reusable." ... they "harvest Open Access content from
over 50,000 publishers and repositories, and make it easy to find, track, and use."
-- [Unpaywall website](https://unpaywall.org/).

Unpaywall is an "open database of free scholarly articles." It includes "data from open indexes like Crossref 
and DOAJ where it exists." Data comes from "monitoring over 50,000 unique online content hosting locations, 
including Gold OA journals, Hybrid journals, institutional repositories, and disciplinary repositories." 
"Unpaywall assigns an OA Status to every article." "There are five possible values: closed, green, gold, 
hybrid, and bronze."
” _- source: [Unpaywall](https://unpaywall.org/)_ 
and [data details](https://unpaywall.org/data-format)

## Latest schema
``` eval_rst
.. csv-table::
   :file: ../schemas/unpaywall_latest.csv
   :width: 100%
   :header-rows: 1
```